cdist-type__grafana_dashboard(7)
================================

NAME
----
cdist-type__grafana_dashboard - Install Grafana (https://grafana.com)


DESCRIPTION
-----------
This cdist type adds the Grafana repository, installs the grafana package, and sets the server to start on boot.

This is a singleton type.

REQUIRED PARAMETERS
-------------------
None.


OPTIONAL PARAMETERS
-------------------
None.


EXAMPLES
--------

.. code-block:: sh

    __grafana_dashboard


AUTHORS
-------
Kamila Součková <kamila@ksp.sk>


COPYING
-------
Copyright \(C) 2017 Kamila Součková. You can redistribute it
and/or modify it under the terms of the GNU General Public License as
published by the Free Software Foundation, either version 3 of the
License, or (at your option) any later version.
